@@ -17,7 +17,7 @@ require Exporter;
 
 @ISA       = qw(Exporter);
 @EXPORT_OK = qw(encrypt decrypt encrypt_hex decrypt_hex);
-$VERSION   = '2.00';
+$VERSION   = '2.05';
 
 
 ########################################
@@ -109,7 +109,7 @@ sub padding (\$;$)
 			# ...check whether it works as expected
 			for my $i (0 .. $bs-1)
 			{
-				my $len = length $padding->(' ' x $i, $bs, 'e') // 0;
+				my $len = length($padding->(' ' x $i, $bs, 'e') || '');
 				die "Provided padding method does not behave properly: Expected $bs bytes, got $len bytes.\n"
 					unless ($len == $bs);
 			}
@@ -236,7 +236,7 @@ sub crypt (\$;$)
 	my $self = shift;
 	my $data = shift;
     
-	$data = ($_ || '') unless length($data);
+	$data = ($_ || '') unless (defined $data && length $data);
 
 	my $bs     = $self->{blocksize};
 	my $mode   = $self->{mode};
@@ -505,8 +505,8 @@ replacement.
 	-cipher    => $cipher,
 	-key       => $key,
 	-padding   => 'oneandzeroes',
-	-keysize   => 8,	# use to override cipher's default
-	-blocksize => 8,	# use to override cipher's default
+	-keysize   => 8,  # use to override cipher's default
+	-blocksize => 8,  # use to override cipher's default
   );
 
 or
@@ -515,13 +515,13 @@ or
 	cipher    => $cipher,
 	key       => $key,
 	padding   => 'oneandzeroes',
-	keysize   => 8,		# use to override cipher's default
-	blocksize => 8,		# use to override cipher's default
+	keysize   => 8,  # use to override cipher's default
+	blocksize => 8,  # use to override cipher's default
   });
 
-or
+or (only key and cipher can be passed this way)
 
-  $ecb = Crypt::ECB->new($key,'Blowfish');
+  $ecb = Crypt::ECB->new($key, 'Blowfish');
   $ecb = Crypt::ECB->new($key);	# DES is assumed
 
 The following options are recognized: cipher, key, keysize, blocksize 
@@ -535,11 +535,11 @@ B<cipher()> before you can start crypting.
 
   $ecb = Crypt::ECB->new;
   $ecb->cipher('Blowfish');
-  $ecb->key('Some_key');
+  $ecb->key('some_key');
 
   print $ecb->cipher;	# Blowfish
   print $ecb->module;	# Crypt::Blowfish
-  print $ecb->key;	# Some_key
+  print $ecb->key;	# some_key
 
 or
 
@@ -564,6 +564,18 @@ B<key()> sets the key if given a parameter. It always returns the
 key. Note that most block ciphers require keys of definite length.
 For example DES expects an eight byte key.
 
+=head2 keysize(), blocksize()
+
+  $ecb = Crypt::ECB->new;
+  $ecb->cipher('Blowfish');
+
+  $keysize   = $ecb->keysize;
+  $blocksize = $ecb->blocksize;
+
+These methods can be used to retrieve keysize and blocksize as
+reported from the block cipher chosen. They can be used as well to
+override the values that are reported from the cipher module.
+
 =head2 padding()
 
   $ecb->padding('oneandzeroes');
@@ -584,9 +596,9 @@ and 'none'. If the padding style is not set explicitly, 'standard' is used.
   whole block is appended.
 
   'zeroes' (binary safe)
-  This is a variant of the standard method. It pads with "00"s, except the
-  last byte equals the number of padding bytes. So, if the blocksize is 8,
-  then "0A0B0C" will be padded to "0A0B0C0000000005". If the message is
+  This is a variant of the standard method. It pads with null bytes, except
+  the last byte equals the number of padding bytes. So, if the blocksize is
+  8, then "0A0B0C" will be padded to "0A0B0C0000000005". If the message is
   already a multiple of the cipher's block size, then another whole block
   is appended.
 
@@ -602,16 +614,16 @@ and 'none'. If the padding style is not set explicitly, 'standard' is used.
   provided for compatibility with Crypt::Rijndael.
 
   'null'
-  Pads with as many null bytes as necessary to fill the block. If the message
-  is already a multiple of the cipher's block size, then another whole block
-  is appended.
+  Pads with as many null bytes as necessary to fill the block. If the
+  message is already a multiple of the cipher's block size, then another
+  whole block is appended.
   ATTENTION: Can truncate more characters than it should (if the original
   message ended with one or more null bytes).
 
   'space'
   Pads with as many space characters as necessary to fill the block.
-  If the message is already a multiple of the cipher's block size, unlike the
-  other methods NO block is appended.
+  If the message is already a multiple of the cipher's block size, unlike
+  the other methods NO block is appended.
   ATTENTION: Can truncate more characters than it should (if the original
   message ended with one or more space characters).
 
@@ -619,28 +631,20 @@ and 'none'. If the padding style is not set explicitly, 'standard' is used.
   No padding added by Crypt::ECB. You then have to take care of correct
   padding and truncating yourself.
 
-You can also use a custom padding function. To do this, create a function that
-is called like:
+You can also use a custom padding function. To do this, create a function
+that is called like:
 
   $padded_block = function($block, $blocksize, $direction);
 
-where $block is the current block of data, $blocksize is the size to pad to,
+and tell Crypt::ECB to use your function:
+
+  $ecb->padding(\&function);
+
+$block is the current block of data, $blocksize is the size to pad to,
 $direction is "e" for encrypting and "d" for decrypting, and $padded_block
-is the result after padding or truncation. When encrypting, the function should
-always return a string of $blocksize length, and when decrypting, it can expect
-the string coming in to be of that length.
-
-=head2 keysize(), blocksize()
-
-  $ecb = Crypt::ECB->new;
-  $ecb->cipher('Blowfish');
-
-  $keysize   = $ecb->keysize;
-  $blocksize = $ecb->blocksize;
-
-These methods can be used to retrieve keysize and blocksize as
-reported from the block cipher chosen. They can be used as well to
-override the values from the cipher module.
+is the result after padding or truncation. When encrypting, the function
+should always return a string of $blocksize length, and when decrypting,
+it can expect the string coming in to be of that length.
 
 =head2 start(), mode(), crypt(), finish()
 
@@ -682,7 +686,7 @@ B<start()>, B<crypt()> and B<finish()> for you.
 B<encrypt_hex()> and B<decrypt_hex()> are convenience functions
 that operate on ciphertext in a hexadecimal representation.
 These functions can be useful if, for example, you wish to place
-the encrypted information into an e-mail message, Web page or URL.
+the encrypted information into an e-mail message, web page or URL.
 
 =head1 FUNCTIONS
 
