@@ -8,15 +8,17 @@ my $ecb = Crypt::ECB->new;
 
 print "Checking your perl installation for block ciphers compliant with Crypt::ECB...\n";
 
+close STDERR;
+
 foreach $path (@INC)
 {
 	while (<$path/Crypt/*.pm>)
 	{
 		s|^.*Crypt/||;
 		s|\.pm$||;
-		$retval = 0;
-		eval { $retval = $ecb->cipher($_) };
-		print " Found $_.\n" if $retval and ++$ok;
+		eval { $ecb->cipher($_) };
+		printf(" found %-15s (keysize: %2s, blocksize: %2s)\n", $_, $ecb->keysize, $ecb->blocksize)
+			if !$@ and ++$ok;
 	}
 }
 
